@@ -5,5 +5,5 @@ def print_hi():
 def print_hello():
 	print('hello')
 
-if __name__='__main__':
+if __name__=='__main__':
 	print_hi()
\ No newline at end of file
